==> haskell-zlib-0.6.1.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zlib
version: 0.6.1.1
id: zlib-0.6.1.1-IKN2DpYEe8r3bYFvs7BDUW
key: zlib-0.6.1.1-IKN2DpYEe8r3bYFvs7BDUW
license: BSD3
copyright: (c) 2006-2015 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the zlib C library so it has high
    performance. It supports the \"zlib\", \"gzip\" and \"raw\"
    compression formats.
    .
    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
exposed: True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Raw Codec.Compression.Zlib.Internal
hidden-modules: Codec.Compression.Zlib.Stream
abi: 16b90fe98489df5e16a0ca1bffed3a7c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/zlib-0.6.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/zlib-0.6.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/zlib-0.6.1.1
hs-libraries: HSzlib-0.6.1.1-IKN2DpYEe8r3bYFvs7BDUW
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.9.0.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html: /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-0.6.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zlib
version: 0.6.1.2
id: zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
key: zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
license: BSD3
copyright: (c) 2006-2016 Duncan Coutts
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.
    .
    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
exposed: True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Raw Codec.Compression.Zlib.Internal
hidden-modules: Codec.Compression.Zlib.Stream
abi: 3ad6d979659d764883b84a1ec51e430b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/zlib-0.6.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/zlib-0.6.1.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/zlib-0.6.1.2
hs-libraries: HSzlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.9.0.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html: /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
